import { Misc } from "../misc.js";
import { RollDataAjustements } from "../rolldata-ajustements.js";
import { tmrColors, tmrConstants, TMRType, TMRUtility } from "../tmr-utility.js";
import { Debordement } from "./debordement.js";
import { Draconique } from "./draconique.js";

export class Desorientation extends Draconique {
  constructor() {
    super();
  }

  type() { return 'souffle' }
  match(item) { return Draconique.isSouffleDragon(item) && item.name.toLowerCase().includes('désorientation'); }
  manualMessage() { return false }

  async onActorCreateOwned(actor, souffle) {
    const type = Misc.rollOneOf(this._typesPossibles(actor));
    console.log("désorientation", type);
    souffle.name += ": " + TMRType[type].name;
    await this._creerCasesTmr(actor, type, souffle);
  }

  _typesPossibles(actor) {
    const dejaDesorientes = Misc.distinct(actor.data.items.filter(it => this.isCase(it)).map(it => it.type));
    return Object.keys(TMRType).filter(it => !dejaDesorientes.includes(it));
  }

  async onActorDeleteOwned(actor, souffle) {
    await this._supprimerCasesTmr(actor, souffle);
  }

  code() { return 'desorientation' }
  tooltip(linkData) { return `Désorientation, cette case n'existe plus !` }
  img() { return 'icons/svg/explosion.svg' }

  _createSprite(pixiTMR) {
    return pixiTMR.sprite(this.code(),
      {
        color: tmrColors.trounoir, alpha: 1, taille: tmrConstants.full, decallage: { x: 2, y: 2 },
      });
  }

  async _creerCasesTmr(actor, type, souffle) {
    const existants = actor.data.items.filter(it => this.isCase(it)).map(it => it.data.coord);
    let tmrs = TMRUtility.filterTMR(it => it.type == type && !existants.includes(it.coord));
    for (let tmr of tmrs) {
      await this.createCaseTmr(actor, 'Désorientation: ' + tmr.label, tmr, souffle._id);
    }
  }

  async _supprimerCasesTmr(actor, souffle) {
    let caseTmrs = actor.data.items.filter(it => it.data.sourceId == souffle._id);
    for (let casetmr of caseTmrs) {
      await actor.deleteOwnedItem(casetmr._id);
    }
  }

}
